@@ -16,8 +16,8 @@ from ..league_model import LeagueModel
 from .combined_game_model import create_combined_game_model
 
 
-def _produce_league_games(league_model: LeagueModel) -> list[dict[str, Any]]:
-    return [x.model_dump() for x in league_model.games]
+def _produce_league_games(league_model: LeagueModel) -> list[GameModel]:
+    return list(league_model.games)
 
 
 class CombinedLeagueModel(LeagueModel):
@@ -62,6 +62,7 @@ class CombinedLeagueModel(LeagueModel):
         team_identity_map = self.team_identity_map()
         for league_model in self._league_models:
             league_model.clear_session()
+        results: list[list[GameModel]] = []
         with ThreadPoolExecutor(
             min(multiprocessing.cpu_count(), len(self._league_models))
         ) as p:
@@ -72,7 +73,6 @@ class CombinedLeagueModel(LeagueModel):
                 for model in self._league_models
             }
 
-            results = []
             try:
                 for future in as_completed(futures):
                     result = future.result()  # Raises if an exception occurred
@@ -82,10 +82,8 @@ class CombinedLeagueModel(LeagueModel):
                 for f in futures:
                     f.cancel()
                 raise  # Optionally re-raise the exception
-        game_lists = [[GameModel.model_validate(y) for y in x] for x in results]
-
-        for game_list in game_lists:
-            for game_model in game_list:
+        for game_list in results:
+            for game_model in tqdm.tqdm(game_list, desc="Sorting Game Models"):
                 old_game_components = [
                     str(game_model.dt.date() - datetime.timedelta(days=1))
                 ]
@@ -110,6 +108,8 @@ class CombinedLeagueModel(LeagueModel):
                 else:
                     key = "-".join(game_components)
                     games[key] = [game_model]
+        del results
+
         names: dict[str, str] = {}
         coach_names: dict[str, str] = {}
         player_ffill: dict[str, dict[str, Any]] = {}
@@ -117,20 +117,25 @@ class CombinedLeagueModel(LeagueModel):
         coach_ffill: dict[str, dict[str, Any]] = {}
         umpire_ffill: dict[str, dict[str, Any]] = {}
         last_game_number = None
-        for game_models in tqdm.tqdm(games.values(), desc="Combining Game Models"):
-            game_model = create_combined_game_model(  # type: ignore
-                game_models=game_models,
-                venue_identity_map=self.venue_identity_map(),
-                team_identity_map=team_identity_map,
-                player_identity_map=self.player_identity_map(),
-                session=self.session,
-                names=names,
-                coach_names=coach_names,
-                last_game_number=last_game_number,
-                player_ffill=player_ffill,
-                team_ffill=team_ffill,
-                coach_ffill=coach_ffill,
-                umpire_ffill=umpire_ffill,
-            )
-            last_game_number = game_model.game_number
-            yield game_model
+        keys = list(games.keys())
+        with tqdm.tqdm() as pbar:
+            for key in tqdm.tqdm(keys, desc="Combining Game Models"):
+                game_models = games.pop(key)
+                pbar.update(1)
+                pbar.set_description(f"Combining Game Models {len(game_models)}")
+                game_model = create_combined_game_model(  # type: ignore
+                    game_models=game_models,
+                    venue_identity_map=self.venue_identity_map(),
+                    team_identity_map=team_identity_map,
+                    player_identity_map=self.player_identity_map(),
+                    session=self.session,
+                    names=names,
+                    coach_names=coach_names,
+                    last_game_number=last_game_number,
+                    player_ffill=player_ffill,
+                    team_ffill=team_ffill,
+                    coach_ffill=coach_ffill,
+                    umpire_ffill=umpire_ffill,
+                )
+                last_game_number = game_model.game_number
+                yield game_model
