@@ -2,7 +2,7 @@
 
 from typing import Literal
 
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, ConfigDict, Field
 
 from .field_type import TYPE_KEY, FieldType
 
@@ -14,6 +14,13 @@ DIVIDEND_DIVIDEND_COLUMN: Literal["dividend"] = "dividend"
 class DividendModel(BaseModel):
     """The serialisable dividend class."""
 
+    model_config = ConfigDict(
+        validate_assignment=False,
+        revalidate_instances="never",
+        extra="ignore",
+        from_attributes=False,
+    )
+
     pool: str = Field(
         ...,
         json_schema_extra={TYPE_KEY: FieldType.CATEGORICAL},
