@@ -6,7 +6,6 @@ from ...combined.combined_league_model import CombinedLeagueModel
 from ...league import League
 from ..espn.nhl_espn_league_model import NHLESPNLeagueModel
 from ..oddsportal.nhl_oddsportal_league_model import NHLOddsPortalLeagueModel
-from ..sportsdb.nhl_sportsdb_league_model import NHLSportsDBLeagueModel
 
 NHL_TEAM_IDENTITY_MAP: dict[str, str] = {}
 NHL_VENUE_IDENTITY_MAP: dict[str, str] = {}
@@ -22,8 +21,8 @@ class NHLCombinedLeagueModel(CombinedLeagueModel):
             League.NHL,
             [
                 NHLESPNLeagueModel(session, position=0),
-                NHLSportsDBLeagueModel(session, position=1),
-                NHLOddsPortalLeagueModel(session, position=2),
+                NHLOddsPortalLeagueModel(session, position=1),
+                # NHLSportsDBLeagueModel(session, position=2),
                 # NHLSportsReferenceLeagueModel(session, position=3),
             ],
             league_filter,
